<?php
// $Id: luceneapi_node.admin.inc,v 1.10.2.11 2009/10/20 01:16:34 cpliakas Exp $

/**
 * @file
 * Administrative settings for Search Lucene Content.
 *
 * @ingroup luceneapi
 */

/**
 * Content bias settings for Search Lucene Content.
 *
 * @return
 *   A FAPI array passed through system_settings_form().
 */
function luceneapi_node_admin_settings() {
  $form = array();

  $description = 'Content bias allows administrators to set configurable levels'
               .' of importance on certain items when scoring is calculated for'
               .' search results.  Results having matched items with larger'
               .' boost factors are returned higher in searches.  The default'
               .' boost factor for Lucene is <em>1.0</em>.';

  // description of what content bias is
  $form['description'] = array(
    '#value' => t($description),
  );

  // gets array of weights
  $weights = drupal_map_assoc(array(
    '21.0', '13.0', '8.0', '5.0', '3.0', '2.0', '1.0', '0.8', '0.5', '0.3', '0.2', '0.1'
  ));
  $weights['0'] = t("Don't search");

  // field bias settings
  $form['bias_fields'] = array(
    '#type' => 'fieldset',
    '#title' => sprintf('Field bias'),
    '#collapsible' => TRUE,
    '#description' => t('Places importance on text in certain Lucene fields.'),
  );

  // bias for body field
  $variable = 'luceneapi_node:bias:contents';
  $form['bias_fields'][$variable] = array(
    '#type' => 'select',
    '#title' => t('Body text'),
    '#default_value' => variable_get($variable, '1.0'),
    '#options' => $weights,
    '#description' => t('The full rendered content of the page.'),
  );

  // adds bias fields
  $fields = module_invoke_all('luceneapi_node_bias_fields');
  foreach ($fields as $field => $info) {
    $variable = sprintf('luceneapi_node:bias:%s', $field);
    $form['bias_fields'][$variable] = array(
      '#type' => 'select',
      '#title' => t($info['title']),
      '#default_value' => variable_get($variable, $info['default']),
      '#options' => $weights,
    );
    if (!empty($info['description'])) {
      $form['bias_fields'][$variable]['#description'] = t($info['description']);
    }
  }

  // HTML tag bias settings
  $form['bias_tags'] = array(
    '#type' => 'fieldset',
    '#title' => sprintf('HTML tag bias'),
    '#collapsible' => TRUE,
    '#description' => t('Places importance on text in HTML tags.'),
  );

  // adds bias tags
  $tags = module_invoke_all('luceneapi_node_bias_tags');
  foreach ($tags as $field => $info) {
    $variable = sprintf('luceneapi_node:bias:%s', $field);
    $form['bias_tags'][$variable] = array(
      '#type' => 'select',
      '#title' => t($info['title']),
      '#default_value' => variable_get($variable, $info['default']),
      '#options' => $weights,
    );
    if (!empty($info['description'])) {
      $form['bias_tags'][$variable]['#description'] = t($info['description']);
    }
  }

  // resets weights for "Node property" setting group
  //$weights = drupal_map_assoc(array_reverse(range(0, 10)));
  $weights[0] = t('No bias');

  $description = 'Places importance on certain node properties.  Canges to'
               .' these values are not immediate and will be reflected when'
               .' content is reindexed.';

  // node property bias settings
  $form['property_tags'] = array(
    '#type' => 'fieldset',
    '#title' => sprintf('Node property bias'),
    '#collapsible' => TRUE,
    '#description' => t($description),
  );

  $form['property_tags']['luceneapi_node:bias:sticky'] = array(
    '#type' => 'select',
    '#title' => t('Node is sticky'),
    '#default_value' => variable_get('luceneapi_node:bias:sticky', 0),
    '#options' => $weights,
    '#description' => t('Nodes that are set to be "Sticky at top of lists".'),
  );

  $form['property_tags']['luceneapi_node:bias:promote'] = array(
    '#type' => 'select',
    '#title' => t('Node is promoted'),
    '#default_value' => variable_get('luceneapi_node:bias:promote', 0),
    '#options' => $weights,
    '#description' => t('Nodes that are set to be "Promoted to home page".'),
  );

  $description = 'Adds bias to nodes of certain content types.  Canges to'
               .' these values are not immediate and will be reflected when'
               .' content is reindexed.';

  // content type bias
  $form['type_tags'] = array(
    '#type' => 'fieldset',
    '#title' => sprintf('Content type bias'),
    '#collapsible' => TRUE,
    '#description' => t($description),
  );

  $types = array_map('check_plain', node_get_types('names'));
  foreach ($types as $type => $name) {
    $variable = sprintf('luceneapi_node:bias:type_%s', $type);
    $form['type_tags'][$variable] = array(
      '#type' => 'select',
      '#title' => t($name),
      '#default_value' => variable_get($variable, 0),
      '#options' => $weights,
    );
  }

  return system_settings_form($form);
}